@@ -19,7 +19,7 @@
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.		     */
 /* ------------------------------------------------------------------------- */
 
-/* $Id: i2c-algo-biths.c,v 1.13 2003/07/25 07:56:42 khali Exp $ */
+/* $Id: i2c-algo-biths.c,v 1.16 2005/03/11 20:37:33 khali Exp $ */
 
 #include <linux/kernel.h>
 #include <linux/module.h>
@@ -577,15 +577,14 @@ static int bit_xfer(struct i2c_adapter *i2c_adap,
 
 static u32 bit_func(struct i2c_adapter *i2c_adap)
 {
-	return I2C_FUNC_SMBUS_EMUL | I2C_FUNC_10BIT_ADDR | 
-		I2C_FUNC_PROTOCOL_MANGLING;
+	return I2C_FUNC_I2C | I2C_FUNC_SMBUS_EMUL |
+	       I2C_FUNC_10BIT_ADDR | I2C_FUNC_PROTOCOL_MANGLING;
 }
 
 
 /* -----exported algorithm data: -------------------------------------	*/
 
 static struct i2c_algorithm i2c_algo_biths = {
-	.owner		= THIS_MODULE,
 	.name		= "Bit-shift algorithm",
 	.id		= I2C_ALGO_BIT,
 	.master_xfer	= bit_xfer,
@@ -679,13 +678,9 @@ static _HS_ATTR_ void i2c_tsc_set(struct i2c_algo_biths_data *adap)
 
 static _HS_ATTR_ void i2c_tsc_run(struct i2c_algo_biths_data *adap)
 {
-	unsigned long now, loops, xloops;
-	int d0;
-	xloops = adap->xloops; 
-	__asm__("mull %0"
-		:"=d" (xloops), "=&a" (d0)
-		:"1" (xloops),"0" (current_cpu_data.loops_per_jiffy));
-	loops = xloops * HZ;
+	unsigned long now, loops;
+	loops = ((long long) adap->xloops * current_cpu_data.loops_per_jiffy) >> 32; 
+	loops *= HZ;
 	do
 	{
 		rep_nop();
