@@ -34,6 +34,14 @@
 
 /* ----- global defines ---------------------------------------------------- */
 
+#if I2C_LINUX_2_4_BINARY_COMPATIBILITY
+#define I2C_LOCK_LIST(adap) down(&adap->bus)
+#define I2C_UNLOCK_LIST(adap) up(&adap->bus)
+#else
+#define I2C_LOCK_LIST(adap) down(&adap->list)
+#define I2C_UNLOCK_LIST(adap) up(&adap->list)
+#endif
+
 #define DEB(x) if (i2c_debug>=1) x;
 #define DEB2(x) if (i2c_debug>=2) x;
 
@@ -105,7 +113,9 @@ int i2c_add_adapter(struct i2c_adapter *adap)
 	
 	/* init data types */
 	init_MUTEX(&adap->bus);
+#if !I2C_LINUX_2_4_BINARY_COMPATIBILITY
 	init_MUTEX(&adap->list);
+#endif
 
 	/* inform drivers of new adapters */
 	for (j=0;j<I2C_DRIVER_MAX;j++)
@@ -311,9 +321,9 @@ int i2c_check_addr (struct i2c_adapter *adapter, int addr)
 {
 	int rval;
 
-	down(&adapter->list);
+	I2C_LOCK_LIST(adapter);
 	rval = __i2c_check_addr(adapter, addr);
-	up(&adapter->list);
+	I2C_UNLOCK_LIST(adapter);
 
 	return rval;
 }
@@ -326,7 +336,7 @@ int i2c_attach_client(struct i2c_client *client)
 	if (i2c_check_addr(client->adapter,client->addr))
 		return -EBUSY;
 
-	down(&adapter->list);
+	I2C_LOCK_LIST(adapter);
 	for (i = 0; i < I2C_CLIENT_MAX; i++)
 		if (NULL == adapter->clients[i])
 			break;
@@ -334,11 +344,11 @@ int i2c_attach_client(struct i2c_client *client)
 		printk(KERN_WARNING 
 		       " i2c-core.o: attach_client(%s) - enlarge I2C_CLIENT_MAX.\n",
 			client->name);
-		up(&adapter->list);
+		I2C_UNLOCK_LIST(adapter);
 		return -ENOMEM;
 	}
 	adapter->clients[i] = client;
-	up(&adapter->list);
+	I2C_UNLOCK_LIST(adapter);
 	
 	if (adapter->client_register) 
 		if (adapter->client_register(client)) 
@@ -371,7 +381,7 @@ int i2c_detach_client(struct i2c_client *client)
 			return res;
 		}
 
-	down(&adapter->list);
+	I2C_LOCK_LIST(adapter);
 	for (i = 0; i < I2C_CLIENT_MAX; i++)
 		if (client == adapter->clients[i])
 			break;
@@ -379,11 +389,11 @@ int i2c_detach_client(struct i2c_client *client)
 		printk(KERN_WARNING " i2c-core.o: unregister_client "
 				    "[%s] not found\n",
 			client->name);
-		up(&adapter->list);
+		I2C_UNLOCK_LIST(adapter);
 		return -ENODEV;
 	}
 	adapter->clients[i] = NULL;
-	up(&adapter->list);
+	I2C_UNLOCK_LIST(adapter);
 
 	DEB(printk(KERN_DEBUG "i2c-core.o: client [%s] unregistered.\n",client->name));
 	return 0;
@@ -391,21 +401,20 @@ int i2c_detach_client(struct i2c_client *client)
 
 static void i2c_inc_use_client(struct i2c_client *client)
 {
-	if(client->driver->owner)
-		__MOD_INC_USE_COUNT(client->driver->owner);
-	if(client->adapter->owner)
-		__MOD_INC_USE_COUNT(client->adapter->owner);
+	if (client->driver->inc_use != NULL)
+		client->driver->inc_use(client);
+	if (client->adapter->inc_use != NULL)
+		client->adapter->inc_use(client->adapter);
 }
 
 static void i2c_dec_use_client(struct i2c_client *client)
 {
-	if(client->driver->owner)
-		__MOD_DEC_USE_COUNT(client->driver->owner);
-	if(client->adapter->owner)
-		__MOD_DEC_USE_COUNT(client->adapter->owner);
+	if (client->driver->dec_use != NULL)
+		client->driver->dec_use(client);
+	if (client->adapter->dec_use != NULL)
+		client->adapter->dec_use(client->adapter);
 }
 
-#if 0 /* just forget about this for now --km */
 struct i2c_client *i2c_get_client(int driver_id, int adapter_id, 
 					struct i2c_client *prev)
 {
@@ -472,7 +481,6 @@ struct i2c_client *i2c_get_client(int driver_id, int adapter_id,
 
 	return 0;
 }
-#endif
 
 int i2c_use_client(struct i2c_client *client)
 {
@@ -582,7 +590,7 @@ ssize_t i2cproc_bus_read(struct file * file, char * buf,size_t count,
 	/* Order will hold the indexes of the clients
 	   sorted by address */
 	order_nr=0;
-	down(&adap->list);
+	I2C_LOCK_LIST(adap);
 	for (j = 0; j < I2C_CLIENT_MAX; j++) {
 	    if ((client = adap->clients[j]) && 
 		(client->driver->id != I2C_DRIVERID_I2CDEV))  {
@@ -605,7 +613,7 @@ ssize_t i2cproc_bus_read(struct file * file, char * buf,size_t count,
 			   client->name,
 			   client->driver->name);
 	}
-	up(&adap->list);
+	I2C_UNLOCK_LIST(adap);
 	up(&core_lists);
 	
 	len = len - file->f_pos;
@@ -636,7 +644,7 @@ static int i2cproc_register(struct i2c_adapter *adap, int bus)
 	}
 	    
 	proc_entry->proc_fops = &i2cproc_operations;
-	proc_entry->owner = adap->owner;
+	proc_entry->owner = THIS_MODULE;
 	adap->inode = proc_entry->low_ino;
 	return 0;
 }
@@ -806,7 +814,7 @@ int i2c_probe(struct i2c_adapter *adapter,
 		   at all */
 		found = 0;
 
-		for (i = 0; !found && (address_data->force[i] != I2C_CLIENT_END); i += 3) {
+		for (i = 0; !found && (address_data->force[i] != I2C_CLIENT_END); i += 2) {
 			if (((adap_id == address_data->force[i]) || 
 			     (address_data->force[i] == ANY_I2C_BUS)) &&
 			     (addr == address_data->force[i+1])) {
@@ -856,7 +864,7 @@ int i2c_probe(struct i2c_adapter *adapter,
 			if (addr == address_data->normal_i2c[i]) {
 				found = 1;
 				DEB2(printk(KERN_DEBUG "i2c-core.o: found normal i2c entry for adapter %d, "
-				            "addr %02x", adap_id,addr));
+				            "addr %02x\n", adap_id, addr));
 			}
 		}
 
@@ -1474,9 +1482,7 @@ EXPORT_SYMBOL(i2c_add_driver);
 EXPORT_SYMBOL(i2c_del_driver);
 EXPORT_SYMBOL(i2c_attach_client);
 EXPORT_SYMBOL(i2c_detach_client);
-#if 0
 EXPORT_SYMBOL(i2c_get_client);
-#endif
 EXPORT_SYMBOL(i2c_use_client);
 EXPORT_SYMBOL(i2c_release_client);
 EXPORT_SYMBOL(i2c_check_addr);
