@@ -52,7 +52,7 @@ static int i2c_sysctl_chips(ctl_table * table, int *name, int nlen,
 				void *newval, size_t newlen,
 				void **context);
 
-#define SENSORS_ENTRY_MAX 20
+#define SENSORS_ENTRY_MAX 24
 static struct ctl_table_header *i2c_entries[SENSORS_ENTRY_MAX];
 
 static struct i2c_client *i2c_clients[SENSORS_ENTRY_MAX];
@@ -123,9 +123,12 @@ static char *generate_name(struct i2c_client *client, const char *prefix)
    ctl_template should be a template of the newly created directory. It is
    copied in memory. The extra2 field of each file is set to point to client.
    If any driver wants subdirectories within the newly created directory,
-   this function must be updated!  */
+   this function must be updated! 
+   controlling_mod is the controlling module. It should usually be
+   THIS_MODULE when calling. */
 int i2c_register_entry(struct i2c_client *client, const char *prefix,
-		       struct ctl_table *ctl_template)
+			   ctl_table *ctl_template,
+			   struct module *controlling_mod)
 {
 	struct { struct ctl_table root[2], dev[2], sensors[2]; } *tbl;
 	struct ctl_table_header *hdr;
@@ -177,6 +180,7 @@ int i2c_register_entry(struct i2c_client *client, const char *prefix,
 	hdr = register_sysctl_table(tbl->root, 0);
 	if (!hdr)
 		goto out_free_tbl;
+	hdr->ctl_table->child->child->de->owner = controlling_mod;
 
 	i2c_entries[id] = hdr;
 	i2c_clients[id] = client;
@@ -491,7 +495,7 @@ static int i2c_parse_reals(int *nrels, void *buffer, int bufsize,
 		/* Skip everything until we hit whitespace */
 		while (bufsize && 
 		       !((ret=get_user(nextchar, (char *) buffer))) &&
-		       isspace((int) nextchar)) {
+		       !isspace((int) nextchar)) {
 			bufsize--;
 			((char *) buffer)++;
 		}
@@ -714,7 +718,7 @@ int i2c_detect(struct i2c_adapter *adapter,
 #ifdef DEBUG
 					printk
 					    (KERN_DEBUG "i2c-proc.o: found normal isa_range entry for adapter %d, "
-					     "addr %04x", adapter_id, addr);
+					     "addr %04x\n", adapter_id, addr);
 #endif
 					found = 1;
 				}
@@ -728,7 +732,7 @@ int i2c_detect(struct i2c_adapter *adapter,
 #ifdef DEBUG
 					printk
 					    (KERN_DEBUG "i2c-proc.o: found normal i2c entry for adapter %d, "
-					     "addr %02x", adapter_id, addr);
+					     "addr %02x\n", adapter_id, addr);
 #endif
 				}
 			}
