@@ -63,15 +63,30 @@ static int rpx_install_isr(int irq, void (*func)(void *, void *), void *data)
 	return 0;
 }
 
+static void rpx_inc_use(struct i2c_adapter *adap)
+{
+#ifdef MODULE
+	MOD_INC_USE_COUNT;
+#endif
+}
+
+static void rpx_dec_use(struct i2c_adapter *adap)
+{
+#ifdef MODULE
+	MOD_DEC_USE_COUNT;
+#endif
+}
+
 static struct i2c_algo_8xx_data rpx_data = {
 	.setisr = rpx_install_isr
 };
 
 static struct i2c_adapter rpx_ops = {
-	.owner		= THIS_MODULE,
 	.name		= "m8xx",
 	.id		= I2C_HW_MPC8XX_EPON,
 	.algo_data	= &rpx_data,
+	.inc_use	= rpx_inc_use,
+	.dec_use	= rpx_dec_use,
 };
 
 static int __init i2c_rpx_init(void)
